CYST is a multi-agent discrete-event simulation framework tailored for cybersecurity domain. Its goal is to enable
high-throughput and realistic simulation of cybersecurity interactions in arbitrary infrastructures. The driving force
behind the initial implementation was the need to have an environment for training ML-driven cybersecurity agents; to
have a mean to achieve autonomous cybersecurity.

Autonomous cybersecurity is a distant goal which requires many hurdles to be overcome. CYST aspires to be an important
technology in this regard by providing key functionality, which is not available elsewhere (at least not all in one
package):

- Lightweight simulation of multi-agent cybersecurity scenarios.
- Streamlined integration with ML toolkits.
- Integration of different behavioral models for attackers, defender, users, or observers.
- Hybrid-stochastic simulation.
- Rapid prototyping of attack and defense strategies.
- Integration of simulation and emulation (e.g., IDS in the loop).
- Smooth transition of agents into the real world.
- Automated generation of realistic cybersecurity scenarios.
- Extensible transformation of simulation artifacts into flows, etc.
- Comprehensive visualization of attack progress.
- Support for stealth and evasive actions.
- Support for multi-agent collaboration and communication.

Naturally, as this is a research project, this functionality is in various state of completion. But we are getting
there. CYST is being developed in the context of several research projects:

- AI-Dojo (https://www.muni.cz/en/research/projects/62788)
- BEAST (https://www.muni.cz/en/research/projects/49127)
- C4e (https://c4e.cz/)

The full documentation can be found here:

https://muni.cz/go/cyst/